<?php

/*
Plugin Name: Colibri Interactive Portfolios
Plugin URI: http://www.colibri-interactive.com
Description: Enables the portfolio post type for Colibri Interactive Themes
Version: 1.0
Author: Colibri Interactive
Author URI: http://www.colibri-interactive.com
*/

if ( ! class_exists( 'CI_Portfolio_Post_Type' ) ) :

class CI_Portfolio_Post_Type {

	function __construct() {

		// PLUGIN ACTIVATION
		register_activation_hook( __FILE__, array( &$this, 'plugin_activation' ) );

		// TRANSLATION
		load_plugin_textdomain( 'ciframework', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		// PORTFOLIO THUMBNAILS
		add_theme_support( 'post-thumbnails', array( 'portfolio' ) );

		add_action( 'init', array( &$this, 'portfolio_init' ) );
		add_action( 'manage_posts_custom_column', array( &$this, 'display_thumbnail' ), 10, 1 );
		add_action( 'restrict_manage_posts', array( &$this, 'add_taxonomy_filters' ) );
		add_action( 'right_now_content_table_end', array( &$this, 'add_portfolio_counts' ) );
		add_action( 'admin_head', array( &$this, 'portfolio_icon' ) );
		add_action( 'admin_portfolio', array( &$this, 'ci_create_portfolio_sort_page') );
		add_action( 'wp_ajax_portfolio_sort', array( &$this, 'ci_save_portfolio_sorted_order' ) );
		add_action( 'wp_ajax_portfolio_cat_sort', array( &$this, 'ci_save_portfolio_cat_sorted_order' ) );
		add_filter( 'manage_edit-portfolio_columns', array( &$this, 'add_thumbnail_column'), 10, 1 );

		add_action( 'portfolio_category_edit_form_fields', 'portfolios_taxonomy_custom_fields', 10, 2 );
	    add_action( 'portfolio_category_add_form_fields', 'portfolios_taxonomy_custom_fields', 10, 2 );

	    add_action( 'created_portfolio_category', 'save_taxonomy_portfolio_custom_fields', 10, 2 );
	    add_action( 'edited_portfolio_category', 'save_taxonomy_portfolio_custom_fields', 10, 2 );
	}


	/*--------------------------------------------------------------------*/
	/*	FLUSH REWRITE RULES
	/*--------------------------------------------------------------------*/
	function plugin_activation() {
		$this->portfolio_init();
		flush_rewrite_rules();
	}

	function portfolio_init() {

		// REGISTER THE POST TYPE
		$labels = array(
			'name' 				 => __( 'Portfolios', 'ciframework' ),
			'singular_name' 	 => __( 'Portfolios', 'ciframework' ),
			'add_new' 			 => __( 'Add Portfolio', 'ciframework' ),
			'add_new_item'		 => __( 'Add New Portfolio', 'ciframework' ),
			'edit_item' 		 => __( 'Edit Portfolio', 'ciframework' ),
			'new_item' 			 => __( 'Add New', 'ciframework' ),
			'view_item' 		 => __( 'View Portfolios', 'ciframework' ),
			'search_items' 		 => __( 'Search Portfolios', 'ciframework' ),
			'not_found' 		 => __( 'No portfolio found', 'ciframework' ),
			'not_found_in_trash' => __( 'No portfolio found in trash', 'ciframework' )
		);

		$args = array(
	    	'labels' 			=> $labels,
	    	'public' 			=> true,
			'supports' 			=> array( 'title', 'editor', 'excerpt', 'thumbnail'),
			'capability_type' 	=> 'post',
			'rewrite' 			=> array("slug" => "portfolio"),
			'portfolio_position' 	=> 20,
			'has_archive' 		=> true
		);

		$args = apply_filters('ci_args', $args);

		register_post_type( 'portfolio', $args );


		// REGISTER TAGS
		$taxonomy_portfolio_tag_labels = array(
			'name' 							=> __( 'Portfolio Tags', 'ciframework' ),
			'singular_name' 				=> __( 'Portfolio Tag', 'ciframework' ),
			'search_items' 					=> __( 'Search Portfolio Tags', 'ciframework' ),
			'popular_items' 				=> __( 'Popular Portfolio Tags', 'ciframework' ),
			'all_items' 					=> __( 'All Portfolio Tags', 'ciframework' ),
			'parent_item' 					=> __( 'Parent Portfolio Tag', 'ciframework' ),
			'parent_item_colon' 			=> __( 'Parent Portfolio Tag:', 'ciframework' ),
			'edit_item' 					=> __( 'Edit Portfolio Tag', 'ciframework' ),
			'update_item' 					=> __( 'Update Portfolio Tag', 'ciframework' ),
			'add_new_item' 					=> __( 'Add New Portfolio Tag', 'ciframework' ),
			'new_item_name' 				=> __( 'New Portfolio Tag Name', 'ciframework' ),
			'separate_items_with_commas' 	=> __( 'Separate portfolio tags with commas', 'ciframework' ),
			'add_or_remove_items' 			=> __( 'Add or remove portfolio tags', 'ciframework' ),
			'choose_from_most_used' 		=> __( 'Choose from the most used portfolio tags', 'ciframework' ),
			'portfolio_name' 					=> __( 'Tags', 'ciframework' )
		);

		$taxonomy_portfolio_tag_args = array(
			'labels' => $taxonomy_portfolio_tag_labels,
			'public' => true,
			'show_in_nav_portfolios' => false,
			'show_ui' => true,
			'show_tagcloud' => false,
			'hierarchical' => false,
			'rewrite' => array( 'slug' => 'portfolio_tag' ),
			'show_admin_column' => false,
			'query_var' => true
		);

		register_taxonomy( 'portfolio_tag', array( 'portfolio' ), $taxonomy_portfolio_tag_args );


		// REGISTER CATEGORIES
	    $taxonomy_portfolio_category_labels = array(
			'name' 							=> __( 'Portfolio Categories', 'ciframework' ),
			'singular_name' 				=> __( 'Portfolio Category', 'ciframework' ),
			'search_items' 					=> __( 'Search Portfolio Categories', 'ciframework' ),
			'popular_items'					=> __( 'Popular Portfolio Categories', 'ciframework' ),
			'all_items' 					=> __( 'All Portfolio Categories', 'ciframework' ),
			'parent_item' 					=> __( 'Parent Portfolio Category', 'ciframework' ),
			'parent_item_colon' 			=> __( 'Parent Portfolio Category:', 'ciframework' ),
			'edit_item' 					=> __( 'Edit Portfolio Category', 'ciframework' ),
			'update_item' 					=> __( 'Update Portfolio Category', 'ciframework' ),
			'add_new_item' 					=> __( 'Add New Portfolio Category', 'ciframework' ),
			'new_item_name' 				=> __( 'New Portfolio Category Name', 'ciframework' ),
			'separate_items_with_commas' 	=> __( 'Separate portfolio categories with commas', 'ciframework' ),
			'add_or_remove_items' 			=> __( 'Add or remove portfolio categories', 'ciframework' ),
			'choose_from_most_used' 		=> __( 'Choose from the most used portfolio categories', 'ciframework' ),
			'portfolio_name' 					=> __( 'Categories', 'ciframework' ),
	    );

	    $taxonomy_portfolio_category_args = array(
			'labels' 			=> $taxonomy_portfolio_category_labels,
			'public' 			=> true,
			'show_in_nav_portfolios' => false,
			'show_ui' 			=> true,
			'show_admin_column' => true,
			'show_tagcloud'		=> false,
			'hierarchical' 		=> true,
			'rewrite' 			=> array( 'slug' => 'portfolio_category' ),
			'query_var' 		=> true
	    );

	    register_taxonomy( 'portfolio_category', array( 'portfolio' ), $taxonomy_portfolio_category_args );

	}


	/*--------------------------------------------------------------------*/
	/*	PORTFOLIO EDIT COLUMNS
	/*--------------------------------------------------------------------*/
	function add_thumbnail_column( $columns ) {
		$column_thumb = array( 'thumbnail' => __('Thumbnail','ciframework' ) );
		$columns = array_slice( $columns, 0, 2, true ) + $column_thumb + array_slice( $columns, 1, NULL, true );
		return $columns;
	}

	function display_thumbnail( $column ) {
		global $post;
		switch ( $column ) {
			case 'thumbnail':
				echo get_the_post_thumbnail( $post->ID, array(35, 35) );
				break;
		}
	}


	/*--------------------------------------------------------------------*/
	/*	ADD TAXONOMY FILTERS TO THE ADMIN PAGE                            */
	/*--------------------------------------------------------------------*/
	function add_taxonomy_filters() {
		global $typenow;

		// USE TAXONOMY NAME OR SLUG
		$taxonomies = array( 'portfolio_category', 'portfolio_tag' );

	 	// POST TYPE FOR THE FILTER
		if ( $typenow == 'portfolio' ) {

			foreach ( $taxonomies as $tax_slug ) {
				$current_tax_slug = isset( $_GET[$tax_slug] ) ? $_GET[$tax_slug] : false;
				$tax_obj = get_taxonomy( $tax_slug );
				$tax_name = $tax_obj->labels->name;
				$terms = get_terms($tax_slug);
				if ( count( $terms ) > 0) {
					echo "<select name='$tax_slug' id='$tax_slug' class='postform'>";
					echo "<option value=''>$tax_name</option>";
					foreach ( $terms as $term ) {
						echo '<option value=' . $term->slug, $current_tax_slug == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>';
					}
					echo "</select>";
				}
			}
		}
	}


	/*--------------------------------------------------------------------*/
	/*	ADD PORTFOLIO COUNT TO "RIGHT NOW" DASHBOARD WIDGET               */
	/*--------------------------------------------------------------------*/
	function add_portfolio_counts() {
	        if ( ! post_type_exists( 'portfolio' ) ) {
	             return;
	        }

	        $num_posts = wp_count_posts( 'portfolio' );
	        $num = number_format_i18n( $num_posts->publish );
	        $text = _n( 'Portfolio Item', 'Portfolio Items', intval($num_posts->publish) );
	        if ( current_user_can( 'edit_posts' ) ) {
	            $num = "<a href='edit.php?post_type=portfolio'>$num</a>";
	            $text = "<a href='edit.php?post_type=portfolio'>$text</a>";
	        }
	        echo '<td class="first b b-portfolio">' . $num . '</td>';
	        echo '<td class="t portfolio">' . $text . '</td>';
	        echo '</tr>';

	        if ($num_posts->pending > 0) {
	            $num = number_format_i18n( $num_posts->pending );
	            $text = _n( 'Portfolio Item Pending', 'Portfolio Items Pending', intval($num_posts->pending) );
	            if ( current_user_can( 'edit_posts' ) ) {
	                $num = "<a href='edit.php?post_status=pending&post_type=portfolio'>$num</a>";
	                $text = "<a href='edit.php?post_status=pending&post_type=portfolio'>$text</a>";
	            }
	            echo '<td class="first b b-portfolio">' . $num . '</td>';
	            echo '<td class="t portfolio">' . $text . '</td>';

	            echo '</tr>';
	        }
	}


	/*--------------------------------------------------------------------*/
	/*	PORTFOLIO SORTING
	/*--------------------------------------------------------------------*/
	function ci_create_portfolio_sort_page() {
	    $ci_sort_page = add_subportfolio_page('edit.php?post_type=portfolio', __('Sort Portfolios', 'ciframework'), __('Sort', 'ciframework'), 'edit_posts', basename(__FILE__), array($this, 'ci_portfolio_sort'));

	    add_action('admin_print_styles-' . $ci_sort_page, array($this, 'ci_print_sort_styles')) ;
	    add_action('admin_print_scripts-' . $ci_sort_page , array($this,'ci_print_sort_scripts'));
	}

	//OUTPUT FOR SORTING PAGE
	function ci_portfolio_sort() {

	    $terms = get_terms( 'portfolio_category' );
      $terms = sort_portfolio_cats($terms); ?>

	    <div class="wrap">
			<style>
				.portfolio_list {
					margin-left: 20px;
				}
			</style>
	        <div id="icon-tools" class="icon32"></div>

	        <h2><?php _e('Sort Portfolios', 'ciframework'); ?></h2>

	        <p><?php _e('Click, drag, re-order & repeat as necessary. The item at the top of the list will display first.', 'ciframework'); ?></p>

			<ul class="portfolio_category_list">
			<?php
			$k = 0;
			foreach ($terms as $category) { ?>

				<li id="<?php echo $category->term_id; ?>" class="portfolio-item">
		                        <dl class="portfolio-item-bar">
		                            <dt class="portfolio-item-handle cat-portfolio-item-handle">
		                                <span class="portfolio-item-title"><?php echo $category->name; ?></span>
		                            </dt><!-- END .portfolio-item-handle -->
		                        </dl><!-- END .portfolio-item-bar -->
		                        <ul class="portfolio-item-transport"></ul>
		                        <?php

					$args = array(
						'post_type' => 'portfolio',
						'posts_per_page' => -1,
						'orderby' => 'portfolio_order',
						'order' => 'ASC',
						'tax_query' => array(
							array(
								'taxonomy' => 'portfolio_category',
								'terms' => $category->term_id
							)
						)
					);

				    $portfolios =  new WP_Query( $args );	?>

				    <ul class="portfolio_list portfolio_list_<?php echo $k; $k++; ?>">

		            <?php while( $portfolios->have_posts() ) : $portfolios->the_post();

		                if( get_post_status() == 'publish' ) { ?>

		                    <li id="<?php the_id(); ?>" class="portfolio-item">
		                        <dl class="portfolio-item-bar">
		                            <dt class="portfolio-item-handle">
		                                <span class="portfolio-item-title"><?php the_title(); ?></span>
		                            </dt><!-- END .portfolio-item-handle -->
		                        </dl><!-- END .portfolio-item-bar -->
		                        <ul class="portfolio-item-transport"></ul>
		                    </li><!-- END .portfolio-item -->

		            <?php } endwhile; wp_reset_postdata(); ?>
		        </ul><!-- END #portfolio_list -->
			<?php echo '</li>';	} ?>
			</ul>
	    </div><!-- END .wrap -->

	<?php }

	//ORDER
	function ci_save_portfolio_sorted_order() {
	    global $wpdb;

	    $order = explode(',', $_POST['order']);
	    $counter = 0;

	    foreach($order as $portfolio_id) {
	        $wpdb->update($wpdb->posts, array('portfolio_order' => $counter), array('ID' => $portfolio_id));
	        $counter++;
	    }
	    die(1);
	}

	function ci_save_portfolio_cat_sorted_order() {
	    global $wpdb;

	    $order = explode(',', $_POST['order']);
	    $counter = 0;

	    foreach($order as $portfolio_id) {
	    	$term_meta = get_option( "portfolios_order_id_$portfolio_id" );
	    	$term_meta['portfolios_order_id'] = $counter;
	    	update_option( "portfolios_order_id_$portfolio_id", $term_meta );
	        $counter++;
	    }
	    die(1);
	}

	// SCRIPTS
	function ci_print_sort_scripts() {
	    wp_enqueue_script('jquery-ui-sortable');
	    wp_enqueue_script( 'ci_portfolio_sort', plugins_url( '/js/ci_sort.js', __FILE__ ), array('jquery') );
	}

	// SORTER STYLES
	function ci_print_sort_styles() {
	    wp_enqueue_style ('nav-portfolio');
	}


	/*--------------------------------------------------------------------*/
	/*	CUSTOM ICON FOR POST TYPE
	/*--------------------------------------------------------------------*/
	function portfolio_icon() { ?>
	<style type="text/css" media="screen">
	</style>

	<?php }

}

new CI_Portfolio_Post_Type;

endif;

	function portfolios_taxonomy_custom_fields($tag) {
        $t_id = $tag->term_id; // Get the ID of the term you're editing
        $term_meta = get_option( "portfolios_order_id_$t_id" ); // Do the check
    ?>

<!--     <tr class="form-field">
        <th scope="row" valign="top">
            <label for="portfolios_order_id">Sort Order</label>
        </th>
        <td>
            <input type="text" name="term_meta[portfolios_order_id]" id="term_meta[portfolios_order_id]" size="25" style="width:60%;" value="<?php echo $term_meta['portfolios_order_id'] ? $term_meta['portfolios_order_id'] : ''; ?>"><br />
        </td>
    </tr>
    <br> -->

    <?php
    }

    function save_taxonomy_portfolio_custom_fields( $term_id ) {
        if ( isset( $_POST['term_meta'] ) ) {
            $t_id = $term_id;
            $term_meta = get_option( "portfolios_order_id_$t_id" );
            $cat_keys = array_keys( $_POST['term_meta'] );
                foreach ( $cat_keys as $key ){
                if ( isset( $_POST['term_meta'][$key] ) ){
                    $term_meta[$key] = $_POST['term_meta'][$key];
                }
            }
            //save the option array
            update_option( "portfolios_order_id_$t_id", $term_meta );
        }
    }

    function sort_portfolio_cats($arr) {
		foreach( $arr as $term ) {
			$portfolio_custom_sort_fields = get_option( "portfolios_order_id_$term->term_id" );
			$term->sort_order = $portfolio_custom_sort_fields['portfolios_order_id'];
		}
		usort($arr, 'compare_portfolio_orders');
		return $arr;
	}


	function compare_portfolio_orders($a, $b) {
	    if($a->sort_order == $b->sort_order) {
	        return 0 ;
	    }
	  return ($a->sort_order < $b->sort_order) ? -1 : 1;
	}

